%%%%%%%%%%%%%%%%
%%%
%%
%%  Rendiconti dell'Istituto di Matematica
%%  dell'Universit\`a di Trieste
%%
%%  LaTeX2e Class 
%%%%%%%%%%%%%%%%


%%%%%%%%%    IN LAVORO

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{rendiconti}[2000]

\DeclareOption{twoside}  {\relax}
\DeclareOption{titlepage}{\relax}
\DeclareOption{twocolumn}{\relax}
\DeclareOption{pteqn}{\AtEndOfClass{
      \@addtoreset{equation}{section}
      \def\theequation{\thesection.\arabic{equation}}
}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax
\LoadClass[twoside,onecolumn,notitlepage,10pt,a4paper]{article}

\RequirePackage{latexsym}
\RequirePackage{amsthm}


\setlength {\textwidth}      {12truecm}
\setlength {\textheight}     {18truecm}
\setlength {\oddsidemargin}  {2cm}
\setlength {\evensidemargin} {2cm}
\setlength {\footnotesep}    {10pt}
\def\footnoterule{\medskip\hrule width .2\columnwidth height .8\p@\bigskip}

\renewcommand{\refname}{{\normalsize\centerline{\sc References}}}
\renewcommand{\@openbib@code}{%
  \parskip=2pt
  \topsep=0pt
  \itemsep=0pt
  \parsep=0pt
  \small}
  
% DEFINITION OF PAGESTYLE
\def\ps@RendHead{%
    \let\@oddfoot\@empty\let\@evenfoot\@empty
    \def\@evenhead{\thepage\hfil\leftmark\hfil}%
    \def\@oddhead{{\hfil\rightmark}\hfil\thepage}%
    \let\@mkboth\@gobbletwo
    \let\sectionmark\@gobble
    \let\subsectionmark\@gobble
    }


\newcommand{\@RendicontiPagina}{%
   \renewcommand{\maketitle}{\relax}
   \ClassError{Rendiconti}{Missing \protect\RendicontiPagina\space command}
       {Before you \protect\begin\space
        the document\MessageBreak
        you must use the \protect\RendicontiPagina\space command,
        \MessageBreak with the following 3 arguments:\MessageBreak
        1st-page number, AUTHOR(S) NAME and SHORTENED TITLE}
}

\newcommand{\e}{\MakeLowercase{and }}% lowercase and is imposed in each page

\AtBeginDocument{\@RendicontiPagina}
\newcommand{\RendicontiPagina}[3]{%
      \renewcommand{\@RendicontiPagina}{\relax}
      \AtBeginDocument{%
        \pagestyle{RendHead}
        \setcounter{page}{#1}
      }
      \markboth{\hfil \MakeUppercase{#2} \hfil}{\hfil \MakeUppercase{#3} \hfil}   %
}

\renewcommand{\maketitle}{\par
  \begingroup
    \global\@topnum\z@   % Prevents figures from going at top of page.
    \null
    \vskip 2em%
    \begin{center}%
      {\normalfont\LARGE\bfseries\@title}\\[1.5em]%
      {\large\sc
       \lineskip .5em%
       \begin{tabular}[t]{c}
         \@author
       \end{tabular}\par}\vskip 1.5em%
       \it\@dedicated
    \end{center}%
    \@sommario
    \@summary
    \vskip 1em%
  \endgroup
  \let\true@oddhead\@oddhead
  \renewcommand{\@oddhead}{%
      \@intesta\hfil
      \global\let\@oddhead\true@oddhead
  }
  \setcounter{footnote}{0}%
  \global\let\maketitle\relax
  \global\let\@author\@empty
  \global\let\@dedicated\@empty
  \renewcommand\date{\nopagebreak\bigskip
             \flushright{Received \@date}%
             \global\let\date\relax
             }%
  \AtEndDocument{\date}%
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\dedicated\relax
  \global\let\and\relax
}           

\newcommand{\@sommario}{\relax}
\newcommand{\sommario}[1]{%
  \renewcommand{\@sommario}{%
    \begin{list}{\textsc{Sommario. -}}{%
      \setlength{\leftmargin}{\parindent}
      \setlength{\labelwidth}{1em}
      }\item{\it #1}
    \end{list}
  }
}

\newcommand{\@summary}{\relax}
\newcommand{\summary}[1]{%
  \renewcommand{\@summary}{%
   \centerline{ \begin{minipage}{0.9\textwidth}
\textsc{Abstract.} {\it #1}
\end{minipage}}
   }
}


% the command DOI contains the last part of the DOI code
% It must be redefined in the source file of the paper.
\def\intesta{
  \AtEndDocument{\label{LastPage}}
  \def\@intesta{\vbox{\parskip1ex\rivista 
  \par \numero  (\anno), Art. No. \Art, 
  %pp. \thepage--\pageref{LastPage} (electronic) 
  \pageref{LastPage} pages %(electronic) 
  \par {\footnotesize DOI will be assigned later}
  %\par {\footnotesize  DOI: 10.13137/2464-8728/\DOI}
  \vfill}}
}  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\rivista{Rend.\ Istit.\ Mat.\ Univ.\ Trieste}
\def\numero{{Vol.  NN} }\def\anno{20YY} 
\def\Art{xx}
\def\DOI{xxxxx}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%




\global\let\thanks\relax
\global\let\@thanks\@empty

\newcommand{\@dedicated}{\relax}
\newcommand{\dedicated}[1]
   {\renewcommand{\@dedicated}{#1\vskip 1.3em\relax}}

%%
%% The next command adds a `\seccntend' (usually a point ``.'')
%% after a section-type number
%
\newcommand\seccntend{.}
\def\@seccntformat#1{\csname the#1\endcsname\seccntend\ }
%
%% while the next one selects the \large size for sections,
%% instead of \Large; moreover it flushes the titles to the left.
%
\renewcommand\section{\@startsection {section}{1}{\z@}%
                            {-3.5ex \@plus -1ex \@minus -.2ex}%
                            {2.3ex \@plus.2ex}%
                            {\normalfont\large\bfseries\flushleft}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                            {-3.25ex\@plus -1ex \@minus -.2ex}%
                            {1.5ex \@plus .2ex}%
                            {\normalfont\large\bfseries\flushleft}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                            {-3.25ex\@plus -1ex \@minus -.2ex}%
                            {1.5ex \@plus .2ex}%
                            {\normalfont\normalsize\bfseries\flushleft}}


%%%%%%%%
\def\and{ {\rm and} }
\def\sommario#1{\relax} 
\def\qedname{$\Box$}

\def\auth#1{\begingroup\def\and{ {\rm and} }\sc\ignorespaces#1\endgroup}
\def\bn#1 {{\bf #1} }




\newtheoremstyle{rendiconti_thm}% name
{}%      Space above, empty = `usual value'
{}%      Space below
{\itshape}% Body font
{}%         Indent amount (empty = no indent, \parindent = para indent)
{\scshape}% Thm head font
{.}%
{ }% 
{}% 
%%
\newtheoremstyle{rendiconti_ex}%
{3pt}%
{3pt}%
{\upshape}%
{0pt}%
{\scshape}%
{.}%
{0.5em}%
{}

%%
\theoremstyle{rendiconti_ex}
\newtheorem{exercise}{Exercise}[section]
\newtheorem{exercises}[exercise]{Exercises}
\newtheorem{problem}[exercise]{Problem}
\newtheorem{op}[exercise]{Open Problem}
\newtheorem{remark}[exercise]{Remark}%[section]
\newtheorem{example}[exercise]{Example}%[section]
\newtheorem{examples}[exercise]{Examples}%[section]


\newcommand\keywords[2]{\noindent
\centerline{
\begin{minipage}{0.9\textwidth}
\footnotesize{\noindent Keywords: \textsf{#1}.\\
MS Classification 2020: \textsf{#2}.}
\end{minipage}}
}

\theoremstyle{rendiconti_thm}
\newtheorem{theorem}[exercise]{Theorem}
\newtheorem{proposition}[exercise]{Proposition}%[section]
\newtheorem{corollary}[exercise]{Corollary}%[section]
%\newtheorem{example}[exercise]{Example}%[section]
%\newtheorem{examples}[exercise]{Examples}%[section]
\newtheorem{lemma}[exercise]{Lemma}%[section]
%\newtheorem{remark}[exercise]{Remark}%[section]
\newtheorem{theodef}[exercise]{Theorem and Definition}
\newtheorem{conjecture}[exercise]{Conjecture}
\newtheorem{definition}[exercise]{Definition}
\newtheorem{axiom}[exercise]{Axiom}

\newcommand\authsinfo[1]{
\vspace{1cm}

\footnotesize{
\noindent Authors' addresses:\\[2mm]
#1}}

\newcommand\authinfo[1]{
\vspace{1cm}

\footnotesize{
\noindent Author's address:\\[2mm]
#1}}


\newcommand\email[1]{E-mail: {\tt #1}\\[2mm]}

\endinput
